=======
History
=======

0.1.4 (2020-04-19)
==================

* Combine JSON spec with the template
* Support inline definition for placeholder variables
* Support inline constraint at block declaration
* Support linked decisions
* Infer ADG from specification
* Update examples
* Various bug fixes

0.1.3 (2019-11-30)
==================

* Revise authoring syntax to support decision blocks and constraints
* Revise CLI, with separate commands to compile and to run
* Improve execution
* Add the hurricane example

0.1.2 (2019-09-19)
==================

* Fix bugs

0.1.1 (2019-09-19)
==================

* Support R
* Improve CLI options
* Support a built-in variable {{_n}}, which represents the universe number
* Support "before_execute" and "after_execute" hooks in the JSON spec
* Update examples

0.1.0 (2019-08-26)
==================

* First release on PyPI.
